==> visualpython-0.3.0.tar.gz: visualpython-0.3.0/visualpython/src/numpy/common/NumpyPageRender/parent/privateMethod/index.js <==
define ([
      './_renderParamArrayEditorTitle'
    , './_resetArrayEditor'
    // , './_renderEditorModalOpenBtn'
    , './_renderParamTabBlock'
    , './_renderParamOneArrayEditor'
    , './_renderParamTwoArrayEditor'
    , './_renderParamThreeArrayEditor'
    // , './_renderIndexingEditor'
    , './_renderParamOneArrayIndexValueEditor'
    , './_renderParamInputArrayEditor'
    , './_renderCallVarBlock'
    , './_renderReturnVarBlock'
    , './_renderParamVarBlock'
    , './_renderDtypeBlock'
    , './_renderInputIndexValueBlock'
    , './_renderSelectIndexValueBlock'
    , './_renderSelectAxisBlock'

    , './_renderPostfixCode'
    , './_renderPrefixCode'
    , './_renderAdditionalOptionContainer'
    , './_renderRequiredInputOutputContainer'
    , './_renderUserOption'
], function(
    _renderParamArrayEditorTitle
    , _resetArrayEditor
    // , _renderEditorModalOpenBtn
    , _renderParamTabBlock
    , _renderParamOneArrayEditor
    , _renderParamTwoArrayEditor
    , _renderParamThreeArrayEditor
    // , _renderIndexingEditor
    , _renderParamOneArrayIndexValueEditor
    , _renderParamInputArrayEditor
    , _renderCallVarBlock
    , _renderReturnVarBlock
    , _renderParamVarBlock
    , _renderDtypeBlock
    , _renderInputIndexValueBlock
    , _renderSelectIndexValueBlock
    , _renderSelectAxisBlock

    , _renderPostfixCode
    , _renderPrefixCode
    , _renderAdditionalOptionContainer
    , _renderRequiredInputOutputContainer
    , _renderUserOption
){
    return {
        _renderParamArrayEditorTitle
        , _resetArrayEditor
        // , _renderEditorModalOpenBtn
        , _renderParamTabBlock
        , _renderParamOneArrayEditor
        , _renderParamTwoArrayEditor
        , _renderParamThreeArrayEditor
        // , _renderIndexingEditor
        , _renderParamOneArrayIndexValueEditor
        , _renderParamInputArrayEditor
        , _renderCallVarBlock
        , _renderReturnVarBlock
        , _renderParamVarBlock
        , _renderDtypeBlock
        , _renderInputIndexValueBlock
        , _renderSelectIndexValueBlock
        , _renderSelectAxisBlock

        , _renderPostfixCode
        , _renderPrefixCode
        , _renderAdditionalOptionContainer
        , _renderRequiredInputOutputContainer
        , _renderUserOption
    }
});

==> visualpython-1.0.3.tar.gz: visualpython-1.0.3/visualpython/src/numpy/common/NumpyPageRender/parent/privateMethod/index.js <==
define ([
      './_renderArrayEditorTitle'
    , './_renderParamTabBlock'
    , './_renderParamOneArrayEditor'
    , './_renderParamTwoArrayEditor'
    , './_renderParamOneArrayIndexValueEditor'
    , './_renderParamInputArrayEditor'
    , './_renderCallVarBlock'
    , './_renderReturnVarBlock'
    , './_renderParamVarBlock'
    , './_renderDtypeBlock'
    , './_renderInputIndexValueBlock'
    , './_renderSelectAxisBlock'

    , './_renderAdditionalOptionContainer'
    , './_renderRequiredInputOutputContainer'

], function(
    _renderArrayEditorTitle
    , _renderParamTabBlock
    , _renderParamOneArrayEditor
    , _renderParamTwoArrayEditor
    , _renderParamOneArrayIndexValueEditor
    , _renderParamInputArrayEditor
    , _renderCallVarBlock
    , _renderReturnVarBlock
    , _renderParamVarBlock
    , _renderDtypeBlock
    , _renderInputIndexValueBlock
    , _renderSelectAxisBlock

    , _renderAdditionalOptionContainer
    , _renderRequiredInputOutputContainer
){
    return {
        _renderArrayEditorTitle
        , _renderParamTabBlock
        , _renderParamOneArrayEditor
        , _renderParamTwoArrayEditor
        , _renderParamOneArrayIndexValueEditor
        , _renderParamInputArrayEditor
        , _renderCallVarBlock
        , _renderReturnVarBlock
        , _renderParamVarBlock
        , _renderDtypeBlock
        , _renderInputIndexValueBlock
        , _renderSelectAxisBlock

        , _renderAdditionalOptionContainer
        , _renderRequiredInputOutputContainer

    }
});
